@@ -16,16 +16,14 @@ def test_icingaweb2_login_screen(host, pytestconfig):
     if get_driver() == 'docker':
         pytest.skip("no letsencrypt when running docker")
     address = get_address(pytestconfig.getoption("--ansible-inventory"))
-    print(f'https://{address}/icingaweb2/authentication/login')
     s = requests.Session()
     r = s.get(f'http://{address}/icingaweb2/authentication/login',
               timeout=5, allow_redirects=False)
-    r.status_code = 302
-    s.verify = 'certs'
+    assert r.status_code == 301
     r = s.get(f'https://{address}/icingaweb2/authentication/login',
-              timeout=5)
+              timeout=5, verify='certs')
     cookies = dict(r.cookies)
     r = s.get(f'https://{address}/icingaweb2/authentication/login?_checkCookie=1',
-              cookies=cookies, timeout=5)
+              cookies=cookies, timeout=5, verify='certs')
     r.raise_for_status()
     assert 'Icinga Web 2 Login' in r.text
