@@ -32,21 +32,21 @@ def test_openstack_create_or_update(tmpdir, openstack_name, requests_mock):
 
 
 def test_service_from_host():
-    s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR)
+    s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR, domain='test.com')
     assert s.service_from_host('icinga-host') in ('essential', 'openvpn', 'wekan')
     assert s.service_from_host('cloud-host') == 'cloud'
     assert s.service_from_host('unknown-host') is None
 
 
 def test_set_service_info():
-    s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR)
+    s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR, domain='test.com')
     assert 'bind-host' in s.service2hosts['bind']
     assert len(s.service2hosts['bind']) > 0
     assert ['bind-host'] == s.service2group['bind']
 
 
 def test_update_vpn_dependencies():
-    s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR)
+    s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR, domain='test.com')
     assert s.hosts_with_internal_network(['bind-host']) == []
     assert 'website-host' not in s.service2hosts['openvpn']
     assert 'website-host' not in s.service2hosts['weblate']
@@ -56,3 +56,20 @@ def test_update_vpn_dependencies():
     assert s.hosts_with_internal_network(['icinga-host']) == ['icinga-host']
     s.update_vpn_dependencies()
     assert 'website-host' in s.service2hosts['weblate']
+
+
+def test_ensure_non_empty_service_group(tmpdir):
+    name = 'wekan'
+    s = service.Service(tmpdir, settings.SHARE_DIR,
+                        name=name,
+                        domain='test.com')
+    with pytest.raises(service.Service.NoHost):
+        s.ensure_non_empty_service_group()
+    host = 'HOST'
+    s = service.Service(tmpdir, settings.SHARE_DIR,
+                        name=name,
+                        host=host,
+                        domain='test.com')
+    hosts = s.ensure_non_empty_service_group()
+    assert hosts == [host]
+    assert hosts == s.ensure_non_empty_service_group()
